"""
ASR Types - Type definitions for ASR data structures.
"""

from .definitions import ASRRawData, ASRSegment, ASRWord

__version__ = "1.0.1"

__all__ = [
    "ASRWord",
    "ASRSegment",
    "ASRRawData",
]
